import { PLATFORM_NAME } from './settings.js';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export class PlejdHbAccessory {
    platform;
    accessory;
    device;
    service;
    state;
    constructor(platform, accessory, device) {
        this.platform = platform;
        this.accessory = accessory;
        this.device = device;
        this.state = {
            brightness: accessory.context.brightness ?? 100,
            isOn: accessory.context.isOn ?? false,
        };
        // set accessory information
        this.accessory
            .getService(this.platform.Service.AccessoryInformation)
            .setCharacteristic(this.platform.Characteristic.Manufacturer, PLATFORM_NAME)
            .setCharacteristic(this.platform.Characteristic.Model, this.device.model)
            .setCharacteristic(this.platform.Characteristic.SerialNumber, this.device.identifier.toString());
        if (this.device.isDimmer) {
            // get the LightBulb service if it exists, otherwise create a new LightBulb service
            this.service =
                this.accessory.getService(this.platform.Service.Lightbulb) ||
                    this.accessory.addService(this.platform.Service.Lightbulb);
            this.service
                .getCharacteristic(this.platform.Characteristic.Brightness)
                .onGet(this.getBrightness.bind(this))
                .onSet(this.setBrightness.bind(this));
        }
        else {
            this.service =
                this.accessory.getService(this.platform.Service.Switch) ||
                    this.accessory.addService(this.platform.Service.Switch);
        }
        // register handlers for the On/Off Characteristic
        this.service
            .getCharacteristic(this.platform.Characteristic.On)
            .onSet(this.setOn.bind(this))
            .onGet(this.getOn.bind(this));
        this.service.setCharacteristic(this.platform.Characteristic.Name, this.device.name);
    }
    updateState = (isOn, brightness) => {
        this.platform.log.debug(`Updating Homekit state from ${this.device.name} device state`);
        this.state.isOn = isOn;
        this.service
            .getCharacteristic(this.platform.Characteristic.On)
            .updateValue(isOn);
        if (brightness) {
            this.state.brightness = Math.round(brightness);
            this.service
                .getCharacteristic(this.platform.Characteristic.Brightness)
                .updateValue(this.state.brightness);
        }
        this.accessory.context = this.state;
    };
    setOn = async (value) => await this.platform.plejdService?.updateState(this.device.identifier, value, null);
    getOn = () => this.state.isOn;
    setBrightness = async (value) => await this.platform.plejdService?.updateState(this.device.identifier, this.state.isOn, value);
    getBrightness = () => this.state.brightness;
}
//# sourceMappingURL=PlejdHbAccessory.js.map